==> knative-model-6.7.1-sources.jar: io/fabric8/knative/flows/v1/ParallelBranchBuilder.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ParallelBranchBuilder extends ParallelBranchFluentImpl<ParallelBranchBuilder> implements VisitableBuilder<ParallelBranch,ParallelBranchBuilder>{
  public ParallelBranchBuilder() {
    this(false);
  }
  public ParallelBranchBuilder(Boolean validationEnabled) {
    this(new ParallelBranch(), validationEnabled);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent) {
    this(fluent, false);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ParallelBranch(), validationEnabled);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent,ParallelBranch instance) {
    this(fluent, instance, false);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent,ParallelBranch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withDelivery(instance.getDelivery());
      fluent.withFilter(instance.getFilter());
      fluent.withReply(instance.getReply());
      fluent.withSubscriber(instance.getSubscriber());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ParallelBranchBuilder(ParallelBranch instance) {
    this(instance,false);
  }
  public ParallelBranchBuilder(ParallelBranch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withDelivery(instance.getDelivery());
      this.withFilter(instance.getFilter());
      this.withReply(instance.getReply());
      this.withSubscriber(instance.getSubscriber());
    }
    this.validationEnabled = validationEnabled; 
  }
  ParallelBranchFluent<?> fluent;
  Boolean validationEnabled;
  public ParallelBranch build() {
    ParallelBranch buildable = new ParallelBranch(fluent.getDelivery(),fluent.getFilter(),fluent.getReply(),fluent.getSubscriber());
    return buildable;
  }
  
}

==> knative-model-6.8.0-sources.jar: io/fabric8/knative/flows/v1/ParallelBranchBuilder.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ParallelBranchBuilder extends ParallelBranchFluent<ParallelBranchBuilder> implements VisitableBuilder<ParallelBranch,ParallelBranchBuilder>{
  public ParallelBranchBuilder() {
    this(false);
  }
  public ParallelBranchBuilder(Boolean validationEnabled) {
    this(new ParallelBranch(), validationEnabled);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent) {
    this(fluent, false);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ParallelBranch(), validationEnabled);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent,ParallelBranch instance) {
    this(fluent, instance, false);
  }
  public ParallelBranchBuilder(ParallelBranchFluent<?> fluent,ParallelBranch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ParallelBranch());

    if (instance != null) {
      fluent.withDelivery(instance.getDelivery());
      fluent.withFilter(instance.getFilter());
      fluent.withReply(instance.getReply());
      fluent.withSubscriber(instance.getSubscriber());
      fluent.withDelivery(instance.getDelivery());
      fluent.withFilter(instance.getFilter());
      fluent.withReply(instance.getReply());
      fluent.withSubscriber(instance.getSubscriber());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ParallelBranchBuilder(ParallelBranch instance) {
    this(instance,false);
  }
  public ParallelBranchBuilder(ParallelBranch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ParallelBranch());

    if (instance != null) {
      this.withDelivery(instance.getDelivery());
      this.withFilter(instance.getFilter());
      this.withReply(instance.getReply());
      this.withSubscriber(instance.getSubscriber());
      this.withDelivery(instance.getDelivery());
      this.withFilter(instance.getFilter());
      this.withReply(instance.getReply());
      this.withSubscriber(instance.getSubscriber());
    }
    this.validationEnabled = validationEnabled; 
  }
  ParallelBranchFluent<?> fluent;
  Boolean validationEnabled;
  public ParallelBranch build() {
    ParallelBranch buildable = new ParallelBranch(fluent.buildDelivery(),fluent.buildFilter(),fluent.buildReply(),fluent.buildSubscriber());
    return buildable;
  }
  
}
